==> tine20-allinone_2019.12.5.tar.bz2: Admin/js/Admin-lang-nl_NL-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Dutch (Netherlands) (http://www.transifex.com/tine20/tine20/language/nl_NL/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: nl_NL\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "User, Users"
: [
  "Gebruiker"
 ,"Gebruikers"

]
, "Groups"
: "Groepen"

, "Roles"
: "Rollen"

, "Applications"
: "Toepassingen"

, "Containers"
: "Containers"

, "Shared Tags"
: "Gedeelde tags"

, "Customfields"
: ""

, "Computers"
: ""

, "Access Log, Access Logs"
: [
  ""
 ,""

]
, "Server Information"
: ""

, "ActiveSync Devices"
: ""

, "Admin"
: "Beheer"

, "Refresh"
: ""

, "Name"
: ""

, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Computer, Computers"
: [
  ""
 ,""

]
, "Default Addressbook for new contacts and groups"
: ""

, "Group, Groups"
: [
  "Groep"
 ,"Groepen"

]
, "Application, Applications"
: [
  "Toepassing"
 ,"Toepassingen"

]
, "Config, Configs"
: [
  ""
 ,""

]
, "Configs"
: ""

, "Please wait"
: "Moment..."

, "Updating Memberships"
: ""

, "Failed"
: "Mislukt"

, "Could not save group."
: "Groep kan niet worden bewaard."

, "Errors"
: "Fouten"

, "Please fix the errors noted."
: "Verhelp de genoemde fouten."

, "Group Name"
: "Groep naam"

, "Description"
: "Omschrijving"

, "Visibility"
: ""

, "Display in addressbook"
: ""

, "Hide from addressbook"
: ""

, "Saved in Addressbook"
: ""

, "Group Members"
: ""

, "Transferring {0}..."
: ""

, "Add new group"
: ""

, "Edit Group \"{0}\""
: ""

, "Enable Application"
: ""

, "Disable Application"
: ""

, "Settings"
: ""

, "{0} Settings"
: "{0} Instellingen"

, "enable application"
: "inschakelen toepassing"

, "disable application"
: "uitschakelen toepassing"

, "settings"
: "instellingen"

, "Search:"
: "Zoeken:"

, "disabled"
: "uitgeschakeld"

, "enabled"
: "ingeschakeld"

, "unknown status ({0})"
: "onbekende status ({0})"

, "Displaying application {0} - {1} of {2}"
: "Tonen van toepassing {0} - {1} van {2}"

, "No applications to display"
: "Geen toepassingen te tonen"

, "Order"
: ""

, "Status"
: "Status"

, "Version"
: "Versie"

, "Confirm"
: "Bevestig"

, "Do you really want to delete the selected groups?"
: ""

, "Deleting group(s)..."
: ""

, "Some error occurred while trying to delete the group."
: ""

, "Add Group"
: ""

, "Edit Group"
: ""

, "Delete Group"
: ""

, "Displaying groups {0} - {1} of {2}"
: ""

, "No groups to display"
: ""

, "ID"
: "ID"

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Computer Name"
: ""

, "IP Address"
: "IP adres"

, "Login Time"
: ""

, "Logout Time"
: ""

, "Client Type"
: ""

, "Session ID"
: ""

, "Login Name"
: ""

, "Result"
: ""

, "user blocked"
: ""

, "password expired"
: "wachtwoord verlopen"

, "user disabled"
: ""

, "invalid password"
: ""

, "ambiguous username"
: "gebruikersnaam niet eenduidig"

, "user not found"
: "gebruiker niet gevonden"

, "failure"
: ""

, "success"
: ""

, "Could not save role."
: ""

, "Deleting role..."
: ""

, "Some error occurred while trying to delete the role."
: ""

, "Rights"
: ""

, "Members"
: ""

, "Role Name"
: ""

, "Role"
: ""

, "Add New Role"
: ""

, "Edit Role \"{0}\""
: ""

, "Container Name"
: "Container naam"

, "Type"
: "Type"

, "Container Order"
: ""

, "Container, Containers"
: [
  "Container"
 ,"Containers"

]
, "Model"
: ""

, "personal"
: "persoonlijk"

, "shared"
: "gedeeld"

, "Color"
: "Kleur"

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: "Notitie voor eigenaar"

, "Do you really want to delete the selected roles?"
: ""

, "Deleting role(s)..."
: ""

, "Add Role"
: ""

, "Edit Role"
: ""

, "Delete Role"
: ""

, "Displaying roles {0} - {1} of {2}"
: ""

, "No roles to display"
: ""

, "Do you really want to delete the selected tags?"
: ""

, "Deleting tag(s)..."
: ""

, "Add Tag"
: ""

, "Edit Tag"
: ""

, "Delete Tag"
: ""

, "Displaying tags {0} - {1} of {2}"
: ""

, "No tags to display"
: ""

, "Usage:&#160;"
: ""

, "Label"
: ""

, "Value"
: "Waarde"

, "Default ({0})"
: ""

, "Yes"
: ""

, "No"
: ""

, "Customfield, Customfields"
: [
  ""
 ,""

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Please configure store for this field type"
: ""

, "Record Class"
: ""

, "Given record class not found"
: ""

, "Cancel"
: "Annuleren"

, "OK"
: "OK"

, "Configure store"
: ""

, "Custom field definition"
: ""

, "Text"
: "Tekst"

, "Textarea"
: ""

, "Number"
: "Nummer"

, "Date"
: "Datum"

, "DateTime"
: ""

, "Time"
: "Tijd"

, "Boolean"
: "Boolean"

, "Search Combo"
: ""

, "Key Field"
: ""

, "Record"
: ""

, "Record List"
: ""

, "Length"
: ""

, "Required"
: ""

, "Custom field additional properties"
: ""

, "Tab Panel"
: ""

, "Customfield already exists. Please choose another name."
: ""

, "Enable Account"
: ""

, "Disable Account"
: ""

, "Reset Password"
: ""

, "Reset Pin"
: ""

, "Display name"
: ""

, "Login name"
: ""

, "Last name"
: "Achternaam"

, "First name"
: "Voornaam"

, "Email"
: "Email"

, "Email usage"
: ""

, "Filesystem usage"
: ""

, "OpenID"
: ""

, "Last login at"
: ""

, "Last login from"
: ""

, "Password changed"
: "Wachtwoord gewijzigd"

, "Expires"
: ""

, "Set new password"
: ""

, "Please enter the new password:"
: ""

, "Set new pin"
: ""

, "Please enter the new pin:"
: ""

, "Users"
: ""

, "Samba User, Samba Users"
: [
  ""
 ,""

]
, "Email User, Email Users"
: [
  ""
 ,""

]
, "Domain is not allowed. Check your SMTP domain configuration."
: ""

, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: ""

, "Passwords match!"
: ""

, "Primary group"
: ""

, "Unix"
: ""

, "Home Directory"
: ""

, "Login Shell"
: ""

, "Windows"
: ""

, "Home Drive"
: ""

, "Logon Time"
: ""

, "never logged in"
: ""

, "Home Path"
: ""

, "Logoff Time"
: ""

, "never logged off"
: ""

, "Profile Path"
: ""

, "Password Last Set"
: ""

, "never"
: ""

, "Logon Script"
: ""

, "Password Can Change"
: ""

, "not set"
: ""

, "Password Must Change"
: ""

, "Kick Off Time"
: ""

, "Filesystem Quota"
: ""

, "Quota"
: ""

, "no quota set"
: ""

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: ""

, "Sieve Quota"
: ""

, "Current Sieve size"
: ""

, "Information"
: ""

, "Last Login"
: ""

, "Domain not allowed"
: ""

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "Email Alias"
: ""

, "Add an alias address..."
: ""

, "Forwarding to self"
: ""

, "You are not allowed to set a forward email address that is identical to the users primary email or one of his aliases."
: ""

, "Email Forward"
: ""

, "Add a forward address..."
: ""

, "Forward Only"
: ""

, "Password confirmation"
: ""

, "Repeat password"
: ""

, "Ok"
: ""

, "Account"
: ""

, "Password"
: ""

, "expired"
: ""

, "blocked"
: ""

, "Invalid Status"
: ""

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: ""

, "don't know"
: ""

, "Password set"
: ""

, "User groups"
: ""

, "User roles"
: ""

, "Fileserver"
: ""

, "Filesystem"
: ""

, "IMAP"
: ""

, "SMTP"
: ""

, "Updating Tag"
: ""

, "Could not save tag ({0})"
: ""

, "Allowed Contexts"
: ""

, "Context"
: ""

, "Account Rights"
: ""

, "View"
: ""

, "Use"
: ""

, "Tag Name"
: ""

, "Tag"
: ""

, "Add New Tag"
: ""

, "Edit Tag \"{0}\""
: ""

, "Default IMAP user settings"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "manage access log"
: "Beheer toegangs log"

, "delete access log entries"
: "verwijder toegangs log vermeldingen"

, "manage accounts"
: "Beheer accounts"

, "add and edit users and groups, add group members, change user passwords"
: "toevoegen en bewerken van gebruikers en groepen, toevoegen van groepen, wijzig wachtwoorden van gebruikers"

, "manage applications"
: "Beheer toepassingen"

, "enable and disable applications, edit application settings"
: "in- / uitschakelen van toepassingen, bewerken van toepassings instellingen"

, "manage roles"
: "Beheer van rollen"

, "add and edit roles, add new members to roles, add application rights to roles"
: "toevoegen en bewerken van rollen, toevoegen van nieuwe leden aan rollen, toevoegen van rechten voor toepassingen aan rollen"

, "manage shared tags"
: "Beheer gedeelde tags"

, "add, delete and edit shared tags"
: "toevoegen, verwijderen en bewerken van gedeelde tags"

, "manage computers"
: "beheer van computers"

, "add, delete and edit (samba) computers"
: "toevoegen, verwijderen en bewerken (samba) file servers"

, "manage containers"
: "beheer van containers"

, "add, delete and edit containers and manage container grants"
: "toevoegen, verwijderen en bewerken van containers en het beheren van rechten voor containers"

, "manage customfields"
: ""

, "add and edit customfields"
: ""

, "view access log"
: "bekijk toegangs log"

, "view access log list"
: ""

, "view accounts"
: "bekijk accounts"

, "view accounts list and details"
: ""

, "view applications"
: "bekijk toepassingen"

, "view applications list and details"
: ""

, "view roles"
: "bekijk rollen"

, "view roles list and details"
: ""

, "view computers"
: "bekijk computers"

, "view computers list and details"
: ""

, "view containers"
: "bekijk containers"

, "view personal and shared containers"
: ""

, "view customfields"
: ""

, "view customfields list"
: ""

, "view serverinfo"
: ""

, "view serverinfo list"
: ""

, "view quota usage"
: ""

, "Your container has been changed"
: ""

, "Your container has been changed by %1$s %2$sNote: %3$s"
: ""

, "Could not save tag without (view-)rights"
: ""

, "User"
: "Gebruiker"

, "Access Log"
: ""

, "Computer"
: ""

, "Group"
: "Groep"

, "Application"
: "Toepassing"

, "Config"
: ""

, "Container"
: "Container"

, "Customfield"
: ""

, "Samba User"
: ""

, "Email User"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.08.8.tar.bz2: Admin/js/Admin-lang-nl_NL-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Dutch (Netherlands) (http://www.transifex.com/tine20/tine20/language/nl_NL/)\nLanguage: nl_NL\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Enable Application"
: ""

, "Disable Application"
: ""

, "Settings"
: ""

, "{0} Settings"
: "{0} Instellingen"

, "Search:"
: "Zoeken:"

, "Disabled"
: ""

, "Enabled"
: ""

, "Unknown status ({0})"
: ""

, "Displaying application {0} - {1} of {2}"
: "Tonen van toepassing {0} - {1} van {2}"

, "No applications to display"
: "Geen toepassingen te tonen"

, "Order"
: ""

, "Name"
: ""

, "Status"
: "Status"

, "Version"
: "Versie"

, "Confirm"
: "Bevestig"

, "Do you really want to delete the selected groups?"
: ""

, "Deleting group(s)..."
: ""

, "Failed"
: "Mislukt"

, "Some error occurred while trying to delete the group."
: ""

, "Add Group"
: ""

, "Edit Group"
: ""

, "Delete Group"
: ""

, "Displaying groups {0} - {1} of {2}"
: ""

, "No groups to display"
: ""

, "ID"
: "ID"

, "E-mail"
: ""

, "Description"
: "Omschrijving"

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Errors"
: "Fouten"

, "Please configure store for this field type"
: ""

, "Application, Applications"
: [
  "Toepassing"
 ,"Toepassingen"

]
, "Record Class"
: ""

, "Given record class not found"
: ""

, "Cancel"
: "Annuleren"

, "OK"
: "OK"

, "Configure store"
: ""

, "Model"
: ""

, "Custom field definition"
: ""

, "Text"
: "Tekst"

, "Textarea"
: ""

, "Number"
: "Nummer"

, "Date"
: "Datum"

, "DateTime"
: ""

, "Time"
: "Tijd"

, "Boolean"
: "Boolean"

, "Search Combo"
: ""

, "Key Field"
: ""

, "Record"
: ""

, "Record List"
: ""

, "Type"
: "Type"

, "Label"
: ""

, "Length"
: ""

, "Required"
: ""

, "Custom field additional properties"
: ""

, "Tab Panel"
: ""

, "Group, Groups"
: [
  "Groep"
 ,"Groepen"

]
, "Customfield already exists. Please choose another name."
: ""

, "Customfield, Customfields"
: [
  ""
 ,""

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Yes"
: ""

, "No"
: ""

, "Config, Configs"
: [
  ""
 ,""

]
, "Value"
: "Waarde"

, "Default ({0})"
: ""

, "Computer Name"
: ""

, "Default Addressbook for new contacts and groups"
: ""

, "Please wait"
: "Moment..."

, "Updating Tag"
: ""

, "Could not save tag ({0})"
: ""

, "Please fix the errors noted."
: "Verhelp de genoemde fouten."

, "Allowed Contexts"
: ""

, "Context"
: ""

, "Account Rights"
: ""

, "View"
: ""

, "Use"
: ""

, "Tag Name"
: ""

, "Color"
: "Kleur"

, "Transferring {0}..."
: ""

, "Tag"
: ""

, "Add New Tag"
: ""

, "Edit Tag \"{0}\""
: ""

, "Do you really want to delete the selected tags?"
: ""

, "Deleting tag(s)..."
: ""

, "Add Tag"
: ""

, "Edit Tag"
: ""

, "Delete Tag"
: ""

, "Displaying tags {0} - {1} of {2}"
: ""

, "No tags to display"
: ""

, "Usage:&#160;"
: ""

, "Updating Memberships"
: ""

, "Could not save role."
: ""

, "Deleting role..."
: ""

, "Some error occurred while trying to delete the role."
: ""

, "Rights"
: ""

, "Members"
: ""

, "Role Name"
: ""

, "Role"
: ""

, "Add New Role"
: ""

, "Edit Role \"{0}\""
: ""

, "Do you really want to delete the selected roles?"
: ""

, "Deleting role(s)..."
: ""

, "Add Role"
: ""

, "Edit Role"
: ""

, "Delete Role"
: ""

, "Displaying roles {0} - {1} of {2}"
: ""

, "No roles to display"
: ""

, "Access Log, Access Logs"
: [
  ""
 ,""

]
, "Groups"
: "Groepen"

, "Applications"
: "Toepassingen"

, "Configs"
: ""

, "Domain is not allowed. Check your SMTP domain configuration."
: ""

, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: ""

, "Passwords match!"
: ""

, "Primary group"
: ""

, "Unix"
: ""

, "Home Directory"
: ""

, "Login Shell"
: ""

, "Windows"
: ""

, "Home Drive"
: ""

, "Login Time"
: ""

, "never logged in"
: ""

, "Home Path"
: ""

, "Logout Time"
: ""

, "never logged off"
: ""

, "Profile Path"
: ""

, "Password Last Set"
: ""

, "never"
: ""

, "Logon Script"
: ""

, "Password Can Change"
: ""

, "not set"
: ""

, "Password Must Change"
: ""

, "Kick Off Time"
: ""

, "Filesystem Quota"
: ""

, "Quota"
: ""

, "no quota set"
: ""

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: ""

, "Sieve Quota"
: ""

, "Current Sieve size"
: ""

, "Information"
: ""

, "Last Login"
: ""

, "Domain not allowed"
: ""

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "E-mail Alias"
: ""

, "Add an alias address..."
: ""

, "This alias can be used for sending e-mails."
: ""

, "Forwarding to self"
: ""

, "You are not allowed to set a forwarding e-mail address that is identical to the users primary e-mail or one of his aliases."
: ""

, "E-mail Forward"
: ""

, "Add a forwarding address..."
: ""

, "Forward Only"
: ""

, "Password confirmation"
: ""

, "Repeat password"
: ""

, "Ok"
: ""

, "Account"
: ""

, "First name"
: "Voornaam"

, "Last name"
: "Achternaam"

, "Login name"
: ""

, "Password"
: ""

, "OpenID"
: ""

, "enabled"
: "ingeschakeld"

, "disabled"
: "uitgeschakeld"

, "expired"
: ""

, "blocked"
: ""

, "Invalid Status"
: ""

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: ""

, "Expires"
: ""

, "Visibility"
: ""

, "Display in addressbook"
: ""

, "Hide from addressbook"
: ""

, "Saved in Addressbook"
: ""

, "Last login at"
: ""

, "don't know"
: ""

, "Last login from"
: ""

, "Password set"
: ""

, "User groups"
: ""

, "User roles"
: ""

, "Fileserver"
: ""

, "Filesystem"
: ""

, "IMAP"
: ""

, "SMTP"
: ""

, "User, Users"
: [
  "Gebruiker"
 ,"Gebruikers"

]
, "Users"
: ""

, "Samba User, Samba Users"
: [
  ""
 ,""

]
, "Email User, Email Users"
: [
  ""
 ,""

]
, "Enable Account"
: ""

, "Disable Account"
: ""

, "Reset Password"
: ""

, "Reset Pin"
: ""

, "Display name"
: ""

, "E-mail usage"
: ""

, "Filesystem usage"
: ""

, "Password changed"
: "Wachtwoord gewijzigd"

, "Set new password"
: ""

, "Please enter the new password:"
: ""

, "Set new pin"
: ""

, "Please enter the new pin:"
: ""

, "Group Name"
: "Groep naam"

, "Only system accounts can be added to Addressbook group"
: ""

, "Group Members"
: ""

, "personal"
: "persoonlijk"

, "shared"
: "gedeeld"

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: "Notitie voor eigenaar"

, "Info"
: ""

, "Please create Resources in Addressbook or CoreData."
: ""

, "Container, Containers"
: [
  "Container"
 ,"Containers"

]
, "Container Name"
: "Container naam"

, "Container Order"
: ""

, "Computer, Computers"
: [
  ""
 ,""

]
, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Roles"
: "Rollen"

, "Containers"
: "Containers"

, "Shared Tags"
: "Gedeelde tags"

, "Customfields"
: ""

, "Computers"
: ""

, "Server Information"
: ""

, "ActiveSync Devices"
: ""

, "E-mail Accounts"
: ""

, "Admin"
: "Beheer"

, "Refresh"
: ""

, "Feature is disabled by configuration."
: ""

, "IP Address"
: "IP adres"

, "Client Type"
: ""

, "Session ID"
: ""

, "Login Name"
: ""

, "Result"
: ""

, "user blocked"
: ""

, "password expired"
: "wachtwoord verlopen"

, "user disabled"
: ""

, "invalid password"
: ""

, "ambiguous username"
: "gebruikersnaam niet eenduidig"

, "user not found"
: "gebruiker niet gevonden"

, "failure"
: ""

, "success"
: ""

, "Default IMAP user settings"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "Your container has been changed"
: ""

, "Your container has been changed by %1$s %2$sNote: %3$s"
: ""

, "Manage access log"
: ""

, "Delete access log entries."
: ""

, "Manage accounts"
: ""

, "Add and edit users and groups, add group members, change user passwords."
: ""

, "Manage e-mail accounts"
: ""

, "Add and edit shared and personal e-mail accounts."
: ""

, "Manage applications"
: ""

, "Enable and disable applications, edit application settings."
: ""

, "Manage roles"
: ""

, "Add and edit roles, add new members to roles, add application rights to roles."
: ""

, "Manage shared tags"
: ""

, "Add, delete and edit shared tags."
: ""

, "Manage computers"
: ""

, "Add, delete and edit (samba) computers."
: ""

, "Manage containers"
: ""

, "Add, delete and edit containers and manage container grants."
: ""

, "Manage customfields"
: ""

, "Add and edit customfields."
: ""

, "View access log"
: ""

, "View access log list."
: ""

, "View accounts"
: ""

, "View accounts list and details."
: ""

, "View e-mail accounts"
: ""

, "View shared and personal e-mail accounts."
: ""

, "View applications"
: ""

, "View applications list and details."
: ""

, "View roles"
: ""

, "View roles list and details."
: ""

, "View shared tags"
: ""

, "View shared tags list and details."
: ""

, "View computers"
: ""

, "View computers list and details."
: ""

, "View containers"
: ""

, "View personal and shared containers."
: ""

, "View customfields"
: ""

, "View customfields list."
: ""

, "View serverinfo"
: ""

, "View serverinfo list."
: ""

, "View quota usage"
: ""

, "View quota usage."
: ""



























, "Application"
: "Toepassing"

, "Group"
: "Groep"

, "Customfield"
: ""

, "Config"
: ""

, "Access Log"
: ""

, "User"
: "Gebruiker"

, "Samba User"
: ""

, "Email User"
: ""

, "Container"
: "Container"

, "Computer"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
